@@ -47,32 +47,6 @@ def get_client():
         client = LambdaAPIClient(api_key=API_KEY)
     return client
 
-def check_for_updates():
-    print("[debug] check_for_updates() was called")
-    package = "lambda-cloud-cli"
-    cache_dir = UPDATE_CACHE_FILE.parent
-    cache_dir.mkdir(parents=True, exist_ok=True)
-
-    # Check timestamp
-    if UPDATE_CACHE_FILE.exists():
-        last_checked = datetime.fromtimestamp(UPDATE_CACHE_FILE.stat().st_mtime)
-        if datetime.now() - last_checked < timedelta(hours=UPDATE_CHECK_INTERVAL_HOURS):
-            return  # ⏱ Too soon, skip check
-
-    try:
-        installed = pkg_resources.get_distribution(package).version
-        response = requests.get(f"https://pypi.org/pypi/{package}/json", timeout=3)
-        latest = response.json()["info"]["version"]
-        if installed != latest:
-            typer.secho(f"📢 A new version is available: {installed} → {latest}", fg=typer.colors.YELLOW)
-            typer.echo("👉 Run `lambda-cli self-update` to upgrade.\n")
-    except Exception as e:
-        print(f"[debug] update check failed: {e}")
-        pass
-
-
-    UPDATE_CACHE_FILE.touch()
-
 # ─────────────────────────────────────────────
 # 🚀 CLI Commands
 # ─────────────────────────────────────────────
@@ -305,11 +279,35 @@ def self_update(yes: bool = typer.Option(False, "--yes", help="Skip confirmation
     ])
     typer.secho("✅ Update complete!", fg=typer.colors.GREEN)
 
-@app.callback()
-def main():
-    print("💥 CALLBACK RAN 💥")
-    check_for_updates()
+#try:
+#    current = pkg_resources.get_distribution("lambda-cloud-cli").version
+#    latest = requests.get("https://pypi.org/pypi/lambda-cloud-cli/json", timeout=3).json()["info"]["version"]
+#    if current != latest:
+#        print(f"📢 New version available: {current} → {latest}\n👉 Run: lambda-cli self-update")
+#except:
+#    pass  # fail silently
+
+def should_check_version():
+    UPDATE_CACHE_FILE.parent.mkdir(parents=True, exist_ok=True)
+    if UPDATE_CACHE_FILE.exists():
+        last_checked = datetime.fromtimestamp(UPDATE_CACHE_FILE.stat().st_mtime)
+        if datetime.now() - last_checked < timedelta(hours=UPDATE_CHECK_INTERVAL_HOURS):
+            return False
+    return True
+
+if should_check_version():
+    try:
+        current = pkg_resources.get_distribution("lambda-cloud-cli").version
+        latest = requests.get("https://pypi.org/pypi/lambda-cloud-cli/json", timeout=3).json()["info"]["version"]
+        if current != latest:
+            print(f"📢 New version available: {current} → {latest}\n👉 Run: lambda-cli self-update")
+    except:
+        pass  # fail silently
+
+    # ✅ Update the timestamp
+    UPDATE_CACHE_FILE.touch()
+
+app()
+
 
-if __name__ == "__main__":
-    app()
 
